@@ -40,7 +40,7 @@ class asyncredisPool(BasePool):
                 self._encoding = params["encoding"]
         except KeyError:
             pass
-        if 'max_queries' in kwargs:
+        if "max_queries" in kwargs:
             self._max_queries = kwargs["max_queries"]
 
     def get_loop(self):
@@ -51,9 +51,7 @@ class asyncredisPool(BasePool):
         """
         __init async db initialization
         """
-        self.logger.debug(
-            "Asyncio Redis Pool: Connecting to {}".format(self._dsn)
-        )
+        self.logger.debug("Asyncio Redis Pool: Connecting to {}".format(self._dsn))
         try:
             self._pool = aredis.ConnectionPool.from_url(
                 self._dsn,
@@ -63,31 +61,20 @@ class asyncredisPool(BasePool):
                 decode_responses=True,
                 retry_on_timeout=True,
                 loop=self._loop,
-                **kwargs
-            )
-        except (
-            aredis.exceptions.ConnectionError,
-            aredis.exceptions.RedisError
-        ) as err:
-            raise ProviderError(
-                "Connection error to Redis: {}".format(str(err))
+                **kwargs,
             )
+        except (aredis.exceptions.ConnectionError, aredis.exceptions.RedisError) as err:
+            raise ProviderError("Connection error to Redis: {}".format(str(err)))
         except Exception as err:
-            raise ProviderError(
-                "Unable to connect to Redis: {}".format(str(err))
-            )
+            raise ProviderError("Unable to connect to Redis: {}".format(str(err)))
         # is connected
         if self._pool:
             try:
                 # create the connection and get the properties:
-                self._connection = aredis.StrictRedis(
-                    connection_pool=self._pool
-                )
+                self._connection = aredis.StrictRedis(connection_pool=self._pool)
                 self.properties = await self._connection.info()
             except Exception as err:
-                raise ProviderError(
-                    "Unable to connect to Redis: {}".format(str(err))
-                )
+                raise ProviderError("Unable to connect to Redis: {}".format(str(err)))
             self._connected = True
             self._initialized_on = time.time()
 
@@ -101,13 +88,8 @@ class asyncredisPool(BasePool):
         try:
             if not self._pool:
                 await self._pool.connect()
-            self._connection = aredis.StrictRedis(
-                connection_pool=self._pool
-            )
-        except (
-            aredis.exceptions.ConnectionError,
-            aredis.exceptions.RedisError
-        ) as err:
+            self._connection = aredis.StrictRedis(connection_pool=self._pool)
+        except (aredis.exceptions.ConnectionError, aredis.exceptions.RedisError) as err:
             raise ConnectionError(
                 "Redis Pool is closed o doesnt exists: {}".format(str(err))
             )
@@ -115,10 +97,7 @@ class asyncredisPool(BasePool):
             raise ProviderError("Redis Pool Acquire Error: {}".format(str(err)))
             return False
         if self._connection:
-            db = asyncredis(
-                connection=self._connection,
-                pool=self
-            )
+            db = asyncredis(connection=self._connection, pool=self)
         return db
 
     async def release(self, connection=None):
@@ -151,10 +130,7 @@ class asyncredisPool(BasePool):
             if self._pool:
                 self._pool.disconnect()
             self._connected = False
-        except (
-            aredis.exceptions.ConnectionError,
-            aredis.exceptions.RedisError
-        ) as err:
+        except (aredis.exceptions.ConnectionError, aredis.exceptions.RedisError) as err:
             raise ConnectionError(
                 "Redis Pool is closed o doesnt exists: {}".format(str(err))
             )
@@ -164,7 +140,7 @@ class asyncredisPool(BasePool):
 
     def is_closed(self):
         self._logger.debug("Connection closed: %s" % (not self._connected))
-        return (not self._connected)
+        return not self._connected
 
     async def execute(self, sentence, *args, **kwargs):
         """
@@ -173,35 +149,32 @@ class asyncredisPool(BasePool):
         if self._pool:
             try:
                 result = await self._connection.execute_command(
-                    sentence,
-                    *args,
-                    **kwargs
+                    sentence, *args, **kwargs
                 )
                 return result
             except TypeError as err:
                 raise ProviderError("Execute Error: {}".format(str(err)))
             except (
                 aredis.exceptions.ConnectionError,
-                aredis.exceptions.RedisError
+                aredis.exceptions.RedisError,
             ) as err:
-                raise ProviderError(
-                    "Connection close Error: {}".format(str(err))
-                )
+                raise ProviderError("Connection close Error: {}".format(str(err)))
             except Exception as err:
                 raise ProviderError("Redis Execute Error: {}".format(str(err)))
 
-    async def test_connection(self, key: str = 'TEST_123', optional: str = ''):
+    async def test_connection(self, key: str = "TEST_123", optional: str = ""):
         result = None
         error = None
         try:
-            await self.execute('set', key, optional)
-            result = await self.execute('get', key)
+            await self.execute("set", key, optional)
+            result = await self.execute("get", key)
         except Exception as err:
             error = err
         finally:
-            await self.execute('DEL', key)
+            await self.execute("DEL", key)
             return [result, error]
 
+
 class asyncredis(BaseProvider):
     _provider = "redis"
     _syntax = "json"
@@ -212,13 +185,7 @@ class asyncredis(BaseProvider):
     _loop = None
     _encoding = "utf-8"
 
-    def __init__(self,
-                 dsn="",
-                 connection=None,
-                 pool=None,
-                 loop=None,
-                 params={}
-                 ):
+    def __init__(self, dsn="", connection=None, pool=None, loop=None, params={}):
         super(asyncredis, self).__init__(dsn=dsn, loop=loop, params=params)
         if pool:
             self._pool = pool
@@ -266,9 +233,7 @@ class asyncredis(BaseProvider):
         self.logger.info("AsyncRedis: Connecting to {}".format(self._dsn))
         try:
             if self._pool:
-                self._connection = aredis.StrictRedis(
-                    connection_pool=self._pool
-                )
+                self._connection = aredis.StrictRedis(connection_pool=self._pool)
             else:
                 self._connection = aredis.StrictRedis.from_url(
                     self._dsn,
@@ -277,16 +242,11 @@ class asyncredis(BaseProvider):
                     connect_timeout=self._timeout,
                     decode_responses=True,
                     retry_on_timeout=True,
-                    **kwargs
+                    **kwargs,
                 )
-        except (
-            aredis.exceptions.ConnectionError,
-            aredis.exceptions.RedisError
-        ) as err:
+        except (aredis.exceptions.ConnectionError, aredis.exceptions.RedisError) as err:
             raise ProviderError(
-                "Unable to connect to Redis, connection Refused: {}".format(
-                    str(err)
-                )
+                "Unable to connect to Redis, connection Refused: {}".format(str(err))
             )
         except Exception as err:
             raise ProviderError("Unknown Redis Error: {}".format(str(err)))
@@ -310,7 +270,7 @@ class asyncredis(BaseProvider):
                     conn.disconnect()
                     conn = None
             except Exception as err:
-                logging.exception('Error closing Redis Connection')
+                logging.exception("Error closing Redis Connection")
             finally:
                 del self._connection
                 self._connected = False
@@ -320,28 +280,19 @@ class asyncredis(BaseProvider):
         Execute a command
         """
         try:
-            result = await self._connection.execute_command(
-                sentence,
-                *args,
-                **kwargs
-            )
+            result = await self._connection.execute_command(sentence, *args, **kwargs)
             return result
         except TypeError as err:
             raise ProviderError("Execute Error: {}".format(str(err)))
-        except (
-            aredis.exceptions.ConnectionError,
-            aredis.exceptions.RedisError
-        ) as err:
-            raise ProviderError(
-                "Connection close Error: {}".format(str(err))
-            )
+        except (aredis.exceptions.ConnectionError, aredis.exceptions.RedisError) as err:
+            raise ProviderError("Connection close Error: {}".format(str(err)))
         except Exception as err:
             raise ProviderError("Redis Execute Error: {}".format(str(err)))
 
     async def prepare(self):
         pass
 
-    async def test_connection(self, key:str = 'TEST_123', optional: str =''):
+    async def test_connection(self, key: str = "TEST_123", optional: str = ""):
         result = None
         error = None
         try:
@@ -357,7 +308,7 @@ class asyncredis(BaseProvider):
         self._logger.debug("Connection closed: %s" % (not self._connected))
         return bool(not self._connected)
 
-    async def ping(self, msg: str = ''):
+    async def ping(self, msg: str = ""):
         if msg:
             await self._connection.echo(msg)
         else:
@@ -415,22 +366,18 @@ class asyncredis(BaseProvider):
             raise ProviderError("Redis Exists Error: {}".format(str(err)))
         except Exception as err:
             print(err)
-            raise ProviderError(
-                "Redis Exists Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis Exists Unknown Error: {}".format(str(err)))
 
     async def m_exists(self, *keys):
         """ Existence of multiples Keys """
         if not self._connection:
             await self.connection()
         try:
-            return await self._connection.execute_command('EXISTS', *keys)
+            return await self._connection.execute_command("EXISTS", *keys)
         except (aredis.exceptions.RedisError) as err:
             raise ProviderError("Redis Exists Error: {}".format(str(err)))
         except Exception as err:
-            raise ProviderError(
-                "Redis Exists Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis Exists Unknown Error: {}".format(str(err)))
 
     async def delete(self, key, *keys):
         try:
@@ -438,9 +385,7 @@ class asyncredis(BaseProvider):
         except (aredis.exceptions.RedisError) as err:
             raise ProviderError("Redis Exists Error: {}".format(str(err)))
         except Exception as err:
-            raise ProviderError(
-                "Redis Exists Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis Exists Unknown Error: {}".format(str(err)))
 
     async def expire(self, key, seconds=0):
         try:
@@ -450,9 +395,7 @@ class asyncredis(BaseProvider):
                 "Redis: wrong Expiration Number: {}".format(str(seconds))
             )
         except Exception as err:
-            raise ProviderError(
-                "Redis Expiration Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis Expiration Unknown Error: {}".format(str(err)))
 
     async def expire_at(self, key, timestamp):
         try:
@@ -462,9 +405,7 @@ class asyncredis(BaseProvider):
                 "Redis: wrong Expiration timestamp: {}".format(str(timestamp))
             )
         except Exception as err:
-            raise ProviderError(
-                "Redis Expiration Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis Expiration Unknown Error: {}".format(str(err)))
 
     async def setex(self, key, value, timeout):
         """
@@ -490,9 +431,7 @@ class asyncredis(BaseProvider):
         except (aredis.exceptions.RedisError) as err:
             raise ProviderError("Redis SetEx Error: {}".format(str(err)))
         except Exception as err:
-            raise ProviderError(
-                "Redis SetEx Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis SetEx Unknown Error: {}".format(str(err)))
 
     def persist(self, key):
         """
@@ -502,9 +441,7 @@ class asyncredis(BaseProvider):
         try:
             return self._connection.persist(key)
         except Exception as err:
-            raise ProviderError(
-                "Redis Expiration Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis Expiration Unknown Error: {}".format(str(err)))
 
     async def set_key(self, key, value):
         await self.set(key, value)
@@ -525,9 +462,7 @@ class asyncredis(BaseProvider):
         except (aredis.exceptions.RedisError) as err:
             raise ProviderError("Redis Hmget Error: {}".format(str(err)))
         except Exception as err:
-            raise ProviderError(
-                "Redis Hmget Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis Hmget Unknown Error: {}".format(str(err)))
 
     async def hmset(self, key, mapping):
         """
@@ -538,9 +473,7 @@ class asyncredis(BaseProvider):
         except (aredis.exceptions.RedisError) as err:
             raise ProviderError("Redis Hmset Error: {}".format(str(err)))
         except Exception as err:
-            raise ProviderError(
-                "Redis Hmset Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis Hmset Unknown Error: {}".format(str(err)))
 
     async def hgetall(self, key):
         """
@@ -552,9 +485,7 @@ class asyncredis(BaseProvider):
         except (aredis.exceptions.RedisError) as err:
             raise ProviderError("Redis Hmset Error: {}".format(str(err)))
         except Exception as err:
-            raise ProviderError(
-                "Redis Hmset Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis Hmset Unknown Error: {}".format(str(err)))
 
     async def hget(self, key, name):
         """
@@ -565,9 +496,7 @@ class asyncredis(BaseProvider):
         except (aredis.exceptions.RedisError) as err:
             raise ProviderError("Redis Hget Error: {}".format(str(err)))
         except Exception as err:
-            raise ProviderError(
-                "Redis Hget Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis Hget Unknown Error: {}".format(str(err)))
 
     async def set_hash(self, key, mapping):
         await self.hmset(key, mapping)
@@ -584,9 +513,7 @@ class asyncredis(BaseProvider):
         except (aredis.exceptions.RedisError) as err:
             raise ProviderError("Redis Hmset Error: {}".format(str(err)))
         except Exception as err:
-            raise ProviderError(
-                "Redis Hmset Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis Hmset Unknown Error: {}".format(str(err)))
 
     async def hvals(self, key):
         """
@@ -597,9 +524,7 @@ class asyncredis(BaseProvider):
         except (aredis.exceptions.RedisError) as err:
             raise ProviderError("Redis Hmset Error: {}".format(str(err)))
         except Exception as err:
-            raise ProviderError(
-                "Redis Hmset Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis Hmset Unknown Error: {}".format(str(err)))
 
     async def keys(self, key):
         return await self.hkeys(key)
@@ -616,9 +541,7 @@ class asyncredis(BaseProvider):
         except (aredis.exceptions.RedisError) as err:
             raise ProviderError("Redis Hset Error: {}".format(str(err)))
         except Exception as err:
-            raise ProviderError(
-                "Redis Hset Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis Hset Unknown Error: {}".format(str(err)))
 
     async def hget(self, key, field):
         """
@@ -629,9 +552,7 @@ class asyncredis(BaseProvider):
         except (aredis.exceptions.RedisError) as err:
             raise ProviderError("Redis Hget Error: {}".format(str(err)))
         except Exception as err:
-            raise ProviderError(
-                "Redis Hget Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis Hget Unknown Error: {}".format(str(err)))
 
     async def hexists(self, key, field, value):
         """
@@ -642,9 +563,7 @@ class asyncredis(BaseProvider):
         except (aredis.exceptions.RedisError) as err:
             raise ProviderError("Redis hash exists Error: {}".format(str(err)))
         except Exception as err:
-            raise ProviderError(
-                "Redis hash exists Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis hash exists Unknown Error: {}".format(str(err)))
 
     async def hdel(self, key, field, *fields):
         """
@@ -655,9 +574,7 @@ class asyncredis(BaseProvider):
         except (aredis.exceptions.RedisError) as err:
             raise ProviderError("Redis Hset Error: {}".format(str(err)))
         except Exception as err:
-            raise ProviderError(
-                "Redis Hset Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis Hset Unknown Error: {}".format(str(err)))
 
 
 """
