@@ -52,14 +52,12 @@ from asyncdb.utils import (
     _escapeString,
 )
 
-from asyncdb.providers.sql import (
-    SQLProvider,
-    baseCursor
-)
+from asyncdb.providers.sql import SQLProvider, baseCursor
 
 max_cached_statement_lifetime = 600
 max_cacheable_statement_size = 1024 * 15
 
+
 class pgPool(BasePool):
     _max_queries = 100
     _dsn = "postgres://{user}:{password}@{host}:{port}/{database}"
@@ -68,23 +66,21 @@ class pgPool(BasePool):
     setup_func = None
     _max_clients = 1500
     _min_size = 5
-    application_name = 'Navigator'
+    application_name = "Navigator"
+    _numeric_as_float: bool = False
 
     def __init__(self, dsn="", loop=None, params={}, **kwargs):
-        super(pgPool, self).__init__(
-            dsn=dsn,
-            loop=loop,
-            params=params,
-            **kwargs
-        )
+        super(pgPool, self).__init__(dsn=dsn, loop=loop, params=params, **kwargs)
         if "server_settings" in kwargs:
             self._server_settings = kwargs["server_settings"]
-        if 'application_name' in self._server_settings:
-            self.application_name = self._server_settings['application_name']
+        if "application_name" in self._server_settings:
+            self.application_name = self._server_settings["application_name"]
         if "max_clients" in kwargs:
             self._max_clients = kwargs["max_clients"]
         if "min_size" in kwargs:
             self._min_size = kwargs["min_size"]
+        if "numeric_as_float" in kwargs:
+            self._numeric_as_float = kwargs['numeric_as_float']
 
     def get_event_loop(self):
         return self._loop
@@ -106,16 +102,10 @@ class pgPool(BasePool):
             return json.loads(value)
 
         await connection.set_type_codec(
-            "json",
-            encoder=_encoder,
-            decoder=_decoder,
-            schema="pg_catalog"
+            "json", encoder=_encoder, decoder=_decoder, schema="pg_catalog"
         )
         await connection.set_type_codec(
-            "jsonb",
-            encoder=_encoder,
-            decoder=_decoder,
-            schema="pg_catalog"
+            "jsonb", encoder=_encoder, decoder=_decoder, schema="pg_catalog"
         )
         await connection.set_builtin_type_codec(
             "hstore", codec_name="pg_contrib.hstore"
@@ -127,32 +117,34 @@ class pgPool(BasePool):
         def timedelta_encoder(delta: relativedelta):
             ndelta = delta.normalized()
             return (
-                ndelta.years * 12 + ndelta.months, ndelta.days,
-                (ndelta.hours * 3600 + ndelta.minutes * 60 + ndelta.seconds)
-                * 1_000_000 + ndelta.microseconds
+                ndelta.years * 12 + ndelta.months,
+                ndelta.days,
+                (ndelta.hours * 3600 + ndelta.minutes * 60 + ndelta.seconds) * 1_000_000
+                + ndelta.microseconds,
             )
 
-        await connection.set_type_codec(
-            'interval',
-            schema='pg_catalog',
-            encoder=timedelta_encoder,
-            decoder=timedelta_decoder,
-            format='tuple'
-        )
+        if self._numeric_as_float is True:
+            await connection.set_type_codec(
+                "interval",
+                schema="pg_catalog",
+                encoder=timedelta_encoder,
+                decoder=timedelta_decoder,
+                format="tuple",
+            )
 
         def _uuid_encoder(value):
             if value:
                 val = uuid.UUID(value).bytes
             else:
-                val = b''
+                val = b""
             return val
 
         await connection.set_type_codec(
             "uuid",
             encoder=_uuid_encoder,
             decoder=lambda u: pgproto.UUID(u),
-            schema='pg_catalog',
-            format='binary'
+            schema="pg_catalog",
+            format="binary",
         )
         if self.init_func:
             try:
@@ -172,9 +164,9 @@ class pgPool(BasePool):
             # TODO: pass a setup class for set_builtin_type_codec and a setup for add listener
             server_settings = {
                 "application_name": self.application_name,
-                "idle_in_transaction_session_timeout": "600",
-                "tcp_keepalives_idle": "600",
-                "max_parallel_workers": "16",
+                "idle_in_transaction_session_timeout": "3600",
+                "tcp_keepalives_idle": "3600",
+                "max_parallel_workers": "24",
             }
             server_settings = {**server_settings, **self._server_settings}
             self._pool = await asyncpg.create_pool(
@@ -182,14 +174,12 @@ class pgPool(BasePool):
                 max_queries=self._max_queries,
                 min_size=self._min_size,
                 max_size=self._max_clients,
-                max_inactive_connection_lifetime=100,
-                timeout=5,
+                max_inactive_connection_lifetime=3600,
+                timeout=10,
                 command_timeout=self._timeout,
                 init=self.init_connection,
                 setup=self.setup_connection,
                 loop=self._loop,
-                max_cached_statement_lifetime=max_cached_statement_lifetime,
-                max_cacheable_statement_size=max_cacheable_statement_size,
                 server_settings=server_settings,
             )
         except TooManyConnectionsError as err:
@@ -202,9 +192,7 @@ class pgPool(BasePool):
             )
         except ConnectionRefusedError as err:
             raise ProviderError(
-                "Unable to connect to database, connection Refused: {}".format(
-                    str(err)
-                )
+                "Unable to connect to database, connection Refused: {}".format(str(err))
             )
         except ConnectionDoesNotExistError as err:
             raise ProviderError("Connection Error: {}".format(str(err)))
@@ -252,7 +240,7 @@ class pgPool(BasePool):
             self._logger.error("Interface Warning: {}".format(str(err)))
             return False
         except Exception as err:
-            self._logger.error('Unknown Error on Acquire: {}'.format(str(err)))
+            self._logger.error("Unknown Error on Acquire: {}".format(str(err)))
         if self._connection:
             db = pg(pool=self)
             db.set_connection(self._connection)
@@ -290,37 +278,25 @@ class pgPool(BasePool):
         Close Pool Connection
     """
 
-    async def wait_close(self, gracefully=True, timeout=10):
+    async def wait_close(self, gracefully=True, timeout=1):
         if self._pool:
             # try to closing main connection
             try:
                 if self._connection:
-                    await self._pool.release(self._connection, timeout=2)
+                    await self._pool.release(self._connection, timeout=timeout)
                     self._connection = None
             except (InternalClientError, InterfaceError) as err:
-                raise ProviderError(
-                    "Release Interface Error: {}".format(str(err))
-                )
+                raise ProviderError("Release Interface Error: {}".format(str(err)))
             except Exception as err:
                 raise ProviderError("Release Error: {}".format(str(err)))
             try:
                 if gracefully:
                     await self._pool.expire_connections()
-                    close = asyncio.create_task(self._pool.close())
-                    #close.add_done_callback(_handle_done_tasks)
-                    try:
-                        await asyncio.wait_for(
-                            close,
-                            timeout=timeout,
-                            loop=self._loop
-                        )
-                    except asyncio.exceptions.TimeoutError as err:
-                        #print(traceback.format_exc())
-                        pass
+                    await self._pool.close()
                 # # until end, close the pool correctly:
                 self._pool.terminate()
             except Exception as err:
-                error = f'Pool Exception: {err.__class__.__name__}: {err}'
+                error = f"Pool Exception: {err.__class__.__name__}: {err}"
                 print("Pool Error: {}".format(error))
                 raise ProviderError("Pool Error: {}".format(error))
             finally:
@@ -333,7 +309,7 @@ class pgPool(BasePool):
     async def close(self):
         try:
             if self._connection:
-                await self._pool.release(self._connection, timeout=2)
+                await self._pool.release(self._connection, timeout=1)
                 self._connection = None
         except InterfaceError as err:
             raise ProviderError("Release Interface Error: {}".format(str(err)))
@@ -341,16 +317,7 @@ class pgPool(BasePool):
             raise ProviderError("Release Error: {}".format(str(err)))
         try:
             await self._pool.expire_connections()
-            close = asyncio.create_task(self._pool.close())
-            #close.add_done_callback(_handle_done_tasks)
-            try:
-                await asyncio.wait_for(
-                    close,
-                    timeout=2,
-                    loop=self._loop
-                )
-            except asyncio.exceptions.TimeoutError as err:
-                pass
+            await self._pool.close()
         except Exception as err:
             print("Pool Closing Error: {}".format(str(err)))
         finally:
@@ -359,7 +326,7 @@ class pgPool(BasePool):
 
     def terminate(self, gracefully=True):
         self._loop.run_until_complete(
-            self.wait_close(gracefully=gracefully, timeout=10)
+            self.wait_close(gracefully=gracefully, timeout=1)
         )
 
     """
@@ -372,9 +339,7 @@ class pgPool(BasePool):
                 result = await self._pool.execute(sentence, *args)
                 return result
             except InterfaceError as err:
-                raise ProviderError(
-                    "Execute Interface Error: {}".format(str(err))
-                )
+                raise ProviderError("Execute Interface Error: {}".format(str(err)))
             except Exception as err:
                 raise ProviderError("Execute Error: {}".format(str(err)))
 
@@ -385,11 +350,10 @@ class pglCursor(baseCursor):
     async def __aenter__(self) -> "pglCursor":
         if not self._connection:
             await self.connection()
-        self._cursor = await self._connection.cursor(
-            self._sentence, self._params
-        )
+        self._cursor = await self._connection.cursor(self._sentence, self._params)
         return self
 
+
 class pg(SQLProvider):
     _provider = "postgresql"
     _syntax = "sql"
@@ -401,17 +365,20 @@ class pg(SQLProvider):
     _initialized_on = None
     _query_raw = "SELECT {fields} FROM {table} {where_cond}"
     _server_settings = {}
-    application_name: str = 'Navigator'
+    application_name: str = "Navigator"
+    _numeric_as_float: bool = False
 
-    def __init__(self, dsn='', loop=None, params={}, pool=None, **kwargs):
+    def __init__(self, dsn="", loop=None, params={}, pool=None, **kwargs):
         super(pg, self).__init__(dsn=dsn, loop=loop, params=params, **kwargs)
         if pool:
             self._pool = pool
             self._loop = self._pool.get_event_loop()
         if "server_settings" in kwargs:
             self._server_settings = kwargs["server_settings"]
-        if 'application_name' in self._server_settings:
-            self.application_name = self._server_settings['application_name']
+        if "application_name" in self._server_settings:
+            self.application_name = self._server_settings["application_name"]
+        if "numeric_as_float" in kwargs:
+            self._numeric_as_float = kwargs['numeric_as_float']
 
     async def close(self, timeout=5):
         """
@@ -436,9 +403,7 @@ class pg(SQLProvider):
                         await self._connection.terminate()
                         self._connection = None
                         raise ProviderError(
-                            "Connection Error, Terminated: {}".format(
-                                str(err)
-                            )
+                            "Connection Error, Terminated: {}".format(str(err))
                         )
         except Exception as err:
             raise ProviderError("Close Error: {}".format(str(err)))
@@ -449,12 +414,26 @@ class pg(SQLProvider):
     def terminate(self):
         self._loop.run_until_complete(self.close())
 
+    async def is_in_transaction(self):
+        return self._connection.is_in_transaction()
+
+    def is_connected(self):
+        try:
+            self._connected = not (self._connection.is_closed())
+            return self._connected
+        except Exception as err:
+            self._logger.exception(err)
+            return False
+
     async def connection(self):
+        """connection.
+
+        Get an asyncpg connection
         """
-        Get a connection
-        """
-        if self._connection:
-            return self
+        if self._connection is not None:
+            if not self._connection.is_closed():
+                self._connected = True
+                return self
 
         self._connection = None
         self._connected = False
@@ -484,36 +463,75 @@ class pg(SQLProvider):
                     timeout=self._timeout,
                     max_cached_statement_lifetime=max_cached_statement_lifetime,
                     max_cacheable_statement_size=max_cacheable_statement_size,
-                    server_settings=server_settings
+                    server_settings=server_settings,
                 )
                 await self._connection.set_type_codec(
-                    "json",
-                    encoder=_encoder,
-                    decoder=_decoder,
-                    schema="pg_catalog"
+                    "json", encoder=_encoder, decoder=_decoder, schema="pg_catalog"
                 )
                 await self._connection.set_type_codec(
-                    "jsonb",
-                    encoder=_encoder,
-                    decoder=_decoder,
-                    schema="pg_catalog"
+                    "jsonb", encoder=_encoder, decoder=_decoder, schema="pg_catalog"
                 )
                 await self._connection.set_builtin_type_codec(
                     "hstore", codec_name="pg_contrib.hstore"
                 )
+                # await connection.set_type_codec(
+                #     "interval",
+                #     schema="pg_catalog",
+                #     encoder=timedelta_encoder,
+                #     decoder=timedelta_decoder,
+                #     format="tuple",
+                # )
+                #
+                # if self._numeric_as_float is True:
+                #     await connection.set_type_codec(
+                #         "interval",
+                #         schema="pg_catalog",
+                #         encoder=timedelta_encoder,
+                #         decoder=timedelta_decoder,
+                #         format="tuple",
+                #     )
+                #
+                # def timedelta_decoder(delta: Tuple) -> relativedelta:
+                #     return relativedelta(
+                #         months=delta[0], days=delta[1], microseconds=delta[2]
+                #     )
+                #
+                # def timedelta_encoder(delta: relativedelta):
+                #     ndelta = delta.normalized()
+                #     return (
+                #         ndelta.years * 12 + ndelta.months,
+                #         ndelta.days,
+                #         (ndelta.hours * 3600 + ndelta.minutes * 60 + ndelta.seconds)
+                #         * 1_000_000
+                #         + ndelta.microseconds,
+                #     )
+
+                def _uuid_encoder(value):
+                    if value:
+                        val = uuid.UUID(value).bytes
+                    else:
+                        val = b""
+                    return val
+
+                await connection.set_type_codec(
+                    "uuid",
+                    encoder=_uuid_encoder,
+                    decoder=lambda u: pgproto.UUID(u),
+                    schema="pg_catalog",
+                    format="binary",
+                )
             if self._connection:
-                if self.init_func:
+                self._connected = True
+                if self.init_func is not None:
                     try:
                         await self.init_func(self._connection)
                     except Exception as err:
                         print("Error on Init Connection: {}".format(err))
                         pass
-                self._connected = True
                 self._initialized_on = time.time()
+                self._logger.debug(f'Initialized on: {self._initialized_on}')
         except TooManyConnectionsError as err:
-            raise TooManyConnections(
-                "Too Many Connections Error: {}".format(str(err))
-            )
+            raise TooManyConnections("Too Many Connections Error: {}".format(str(err)))
         except ConnectionDoesNotExistError as err:
             print("Connection Error: {}".format(str(err)))
             raise ProviderError("Connection Error: {}".format(str(err)))
@@ -577,7 +595,7 @@ class pg(SQLProvider):
                 try:
                     self._attributes = stmt.get_attributes()
                     self._columns = [a.name for a in self._attributes]
-                    #self._columns = [a.name for a in stmt.get_attributes()]
+                    # self._columns = [a.name for a in stmt.get_attributes()]
                     self._prepared = stmt
                     self._parameters = stmt.get_parameters()
                 except TypeError:
@@ -615,9 +633,7 @@ class pg(SQLProvider):
         except RuntimeError as err:
             error = "Runtime Error: {}".format(str(err))
             raise ProviderError(error)
-        except (
-            PostgresSyntaxError, UndefinedColumnError, PostgresError
-        ) as err:
+        except (PostgresSyntaxError, UndefinedColumnError, PostgresError) as err:
             error = "Sentence Error: {}".format(str(err))
             raise StatementError(error)
         except (
@@ -646,12 +662,10 @@ class pg(SQLProvider):
             self._columns = [a.name for a in self._attributes]
             self._result = await stmt.fetchrow()
         except RuntimeError as err:
-            error = "Runtime on Query Row Error: {}".format(str(err))
+            error = "Query Row Runtime Error: {}".format(str(err))
             raise ProviderError(error)
-        except (
-            PostgresSyntaxError, UndefinedColumnError, PostgresError
-        ) as err:
-            error = "Sentence on Query Row Error: {}".format(str(err))
+        except (PostgresSyntaxError, UndefinedColumnError, PostgresError) as err:
+            error = "Statement Error: {}".format(str(err))
             raise StatementError(error)
         except (
             asyncpg.exceptions.InvalidSQLStatementNameError,
@@ -661,7 +675,7 @@ class pg(SQLProvider):
             self._loop.call_exception_handler(err)
             raise StatementError(error)
         except Exception as err:
-            error = "Error on Query Row: {}".format(str(err))
+            error = "Query Row Error: {}".format(str(err))
             self._loop.call_exception_handler(err)
             raise Exception(error)
         # finally:
@@ -690,7 +704,7 @@ class pg(SQLProvider):
             raise ProviderError(error)
         except Exception as err:
             error = "Error on Execute: {}".format(str(err))
-            #self._loop.call_exception_handler(err)
+            # self._loop.call_exception_handler(err)
             raise ProviderError(error)
         finally:
             return [result, error]
@@ -709,7 +723,7 @@ class pg(SQLProvider):
             return False
         except Exception as err:
             error = "Error on Execute: {}".format(str(err))
-            #self._loop.call_exception_handler(err)
+            # self._loop.call_exception_handler(err)
             raise Exception(error)
         finally:
             return error
@@ -737,7 +751,6 @@ class pg(SQLProvider):
     Cursor Context
     """
 
-
     async def cursor(self, sentence):
         if not sentence:
             raise EmptyStatement("Sentence is an empty string")
@@ -789,12 +802,7 @@ class pg(SQLProvider):
     """
 
     async def copy_from_table(
-        self,
-        table="",
-        schema="public",
-        output=None,
-        type="csv",
-        columns=None
+        self, table="", schema="public", output=None, type="csv", columns=None
     ):
         """table_copy
         get a copy of table data into a file, file-like object or a coroutine passed on "output"
@@ -820,9 +828,7 @@ class pg(SQLProvider):
             asyncpg.exceptions.InvalidSQLStatementNameError,
             asyncpg.exceptions.UndefinedTableError,
         ) as err:
-            error = "Error on Copy, Invalid Statement Error: {}".format(
-                str(err)
-            )
+            error = "Error on Copy, Invalid Statement Error: {}".format(str(err))
             self._loop.call_exception_handler(err)
             raise StatementError(error)
         except Exception as err:
@@ -830,12 +836,7 @@ class pg(SQLProvider):
             raise Exception(error)
 
     async def copy_to_table(
-        self,
-        table="",
-        schema="public",
-        source=None,
-        type="csv",
-        columns=None
+        self, table="", schema="public", source=None, type="csv", columns=None
     ):
         """copy_to_table
         get data from a file, file-like object or a coroutine passed on "source" and copy into table
@@ -864,9 +865,7 @@ class pg(SQLProvider):
             asyncpg.exceptions.InvalidSQLStatementNameError,
             asyncpg.exceptions.UndefinedTableError,
         ) as err:
-            error = "Error on Copy, Invalid Statement Error: {}".format(
-                str(err)
-            )
+            error = "Error on Copy, Invalid Statement Error: {}".format(str(err))
             self._loop.call_exception_handler(err)
             raise StatementError(error)
         except Exception as err:
@@ -888,10 +887,7 @@ class pg(SQLProvider):
             await self._transaction.commit()
         try:
             result = await self._connection.copy_records_to_table(
-                table_name=table,
-                schema_name=schema,
-                columns=columns,
-                records=source
+                table_name=table, schema_name=schema, columns=columns, records=source
             )
             return result
         except (asyncpg.exceptions.UndefinedTableError) as err:
@@ -901,9 +897,7 @@ class pg(SQLProvider):
             raise StatementError(error)
             return False
         except (InvalidSQLStatementNameError, UndefinedColumnError) as err:
-            error = "Error on Copy, Invalid Statement Error: {}".format(
-                str(err)
-            )
+            error = "Error on Copy, Invalid Statement Error: {}".format(str(err))
             raise StatementError(error)
         except (asyncpg.exceptions.UniqueViolationError) as err:
             error = "Error on Copy, Constraint Violated: {}".format(str(err))
@@ -918,6 +912,7 @@ class pg(SQLProvider):
     """
     Model Logic:
     """
+
     async def column_info(self, tablename):
         """Column Info.
 
@@ -939,7 +934,8 @@ class pg(SQLProvider):
             colinfo = await self._connection.fetch(sql)
             return colinfo
         except Exception as err:
-            self._logger.exception(f'Wrong Table information {tablename!s}')
+            self._logger.exception(f"Wrong Table information {tablename!s}")
+
 
 """
 Registering this Provider
