@@ -11,6 +11,7 @@ TODO:
 import asyncio
 
 import aioredis
+from aioredis.connection import Connection, to_bool
 import objectpath
 import time
 
@@ -29,6 +30,7 @@ class redisPool(BasePool):
     _pool = None
     _connection = None
     _encoding = "utf-8"
+    _connected = False
 
     def __init__(self, dsn="", loop=None, params={}, **kwargs):
         super(redisPool, self).__init__(dsn=dsn, loop=loop, params=params)
@@ -38,7 +40,7 @@ class redisPool(BasePool):
                 self._encoding = params["encoding"]
         except KeyError:
             pass
-        if 'max_queries' in kwargs:
+        if "max_queries" in kwargs:
             self._max_queries = kwargs["max_queries"]
 
     def get_event_loop(self):
@@ -48,7 +50,7 @@ class redisPool(BasePool):
         return self._connection
 
     def is_closed(self):
-        return self._pool.closed
+        return not self._connected
 
     """
     Context magic Methods
@@ -58,7 +60,9 @@ class redisPool(BasePool):
         return self
 
     def __exit__(self, *args):
-        self._loop.run_until_complete(self.release())
+        self._loop.run_until_complete(
+            self.release()
+        )
 
     # Create a redis connection pool
     async def connect(self, **kwargs):
@@ -67,24 +71,19 @@ class redisPool(BasePool):
         """
         self.logger.debug("Redis Pool: Connecting to {}".format(self._dsn))
         try:
-            self._pool = await aioredis.create_pool(
+            self._pool = aioredis.ConnectionPool.from_url(
                 self._dsn,
-                minsize=5,
-                maxsize=self._max_queries,
-                loop=self._loop,
                 encoding=self._encoding,
-                create_connection_timeout=300,
-                **kwargs
+                decode_responses=True,
+                max_connections=self._max_queries,
+                **kwargs,
             )
-        except (aioredis.ProtocolError) as err:
-            raise ConnectionTimeout(
-                "Unable to connect to Redis: {}".format(str(err))
-            )
-        except (aioredis.RedisError) as err:
+            self._connection = aioredis.Redis(connection_pool=self._pool)
+        except (aioredis.exceptions.ConnectionError) as err:
+            raise ConnectionTimeout("Unable to connect to Redis: {}".format(str(err)))
+        except (aioredis.exceptions.RedisError) as err:
             raise ProviderError(
-                "Unable to connect to Redis, connection Refused: {}".format(
-                    str(err)
-                )
+                "Unable to connect to Redis, connection Refused: {}".format(str(err))
             )
         except Exception as err:
             raise ProviderError("Unknown Error: {}".format(str(err)))
@@ -93,47 +92,34 @@ class redisPool(BasePool):
         if self._pool:
             self._connected = True
             self._initialized_on = time.time()
+        return self
 
     async def acquire(self):
         """
         Take a connection from the pool.
         """
-        db = None
-        self._connection = None
         # Take a connection from the pool.
         try:
-            if self._pool.closed:
-                await self._pool.connect()
-            self._connection = await self._pool.acquire()
-        except (aioredis.PoolClosedError) as err:
-            raise ConnectionError(
-                "Redis Pool is already closed: {}".format(str(err))
-            )
-        except (aioredis.ConnectionClosedError) as err:
+            return redis(connection=self._connection, pool=self)
+        except (aioredis.exceptions.ConnectionError) as err:
+            raise ConnectionError("Redis Pool is already closed: {}".format(str(err)))
+        except (aioredis.exceptions.RedisError) as err:
             raise ConnectionError(
                 "Redis Pool is closed o doesnt exists: {}".format(str(err))
             )
         except Exception as err:
             raise ProviderError("Unknown Error: {}".format(str(err)))
             return False
-        if self._connection:
-            db = redis(connection=self._connection, pool=self)
-        return db
 
     async def release(self, connection=None):
         """
         Release a connection from the pool
         """
         if not connection:
-            conn = self._connection
-        else:
-            if isinstance(connection, redis):
-                conn = connection.engine()
-            else:
-                conn = connection
+            return True
         try:
-            if conn:
-                self._pool.release(conn)
+            print(type(connection.get_connection()))
+            await self._pool.release(connection.get_connection())
         except Exception as err:
             raise ProviderError("Release Error: {}".format(str(err)))
 
@@ -142,23 +128,14 @@ class redisPool(BasePool):
         Close Pool
         """
         try:
-
-            if self._pool and self._pool.closed is False:
-                self._pool.close()
-                # also clear:
-                await self._pool.clear()
-                #await asyncio.sleep(1)
-                close = asyncio.create_task(self._pool.wait_closed())
-                try:
-                    await asyncio.wait_for(
-                        close,
-                        timeout=timeout
-                    )
-                except asyncio.exceptions.TimeoutError as err:
-                    pass
-        except (
-            aioredis.errors.PoolClosedError, aioredis.ConnectionClosedError
-        ) as err:
+            if self._connection is not None:
+                await self._connection.close()
+            if self._pool:
+                await self._pool.disconnect(inuse_connections = True)
+                # await self._pool.disconnect()
+            self._connected = False
+            return True
+        except (aioredis.exceptions.ConnectionError) as err:
             raise ProviderError("Connection close Error: {}".format(str(err)))
         except Exception as err:
             logging.exception("Pool Closing Error: {}".format(str(err)))
@@ -170,22 +147,23 @@ class redisPool(BasePool):
         """
         if self._pool:
             try:
-                result = await self._pool.execute(sentence, *args, **kwargs)
+                result = await self._connection.execute_command(
+                    sentence, *args, **kwargs
+                )
                 return result
             except TypeError as err:
                 raise ProviderError("Execute Error: {}".format(str(err)))
-            except aioredis.ProtocolError as err:
+            except aioredis.exceptions.ConnectionError as err:
                 raise ProviderError(
-                    "Connection cannot be decoded or is broken, Error: {}".
-                    format(str(err))
+                    "Connection cannot be decoded or is broken, Error: {}".format(
+                        str(err)
+                    )
                 )
             except (
-                aioredis.errors.PoolClosedError,
-                aioredis.ConnectionClosedError,
+                aioredis.exceptions.ConnectionError,
+                aioredis.exceptions.RedisError
             ) as err:
-                raise ProviderError(
-                    "Connection close Error: {}".format(str(err))
-                )
+                raise ProviderError("Connection close Error: {}".format(str(err)))
             except Exception as err:
                 raise ProviderError("Redis Execute Error: {}".format(str(err)))
 
@@ -202,11 +180,13 @@ class redis(BaseProvider):
 
     def __init__(self, dsn="", connection=None, loop=None, pool=None, params={}):
         super(redis, self).__init__(dsn=dsn, loop=loop, params=params)
+        if connection is not None:
+            self._connection = connection
+            self._connected = True
         if pool:
             self._pool = pool
-            self._connection = aioredis.Redis(connection)
             self._connected = True
-            self._initialized_on = time.time()
+        self._initialized_on = time.time()
         try:
             if params["encoding"]:
                 self._encoding = params["encoding"]
@@ -216,6 +196,7 @@ class redis(BaseProvider):
     """
     Context magic Methods
     """
+
     async def __aenter__(self) -> "BaseProvider":
         if not self._connection:
             await self.connection()
@@ -223,13 +204,22 @@ class redis(BaseProvider):
 
     async def __aexit__(self, exc_type, exc_val, exc_tb) -> None:
         # clean up anything you need to clean up
-        return await self.release()
+        try:
+            return await self.close()
+        except Exception as err:
+            print(err)
+            pass
 
     def __enter__(self):
         return self
 
     def __exit__(self, *args):
-        self.release()
+        try:
+            self._loop.run_until_complete(
+                self.close()
+            )
+        except Exception as err:
+            pass
 
     """
     Properties
@@ -253,24 +243,19 @@ class redis(BaseProvider):
         """
         self._logger.info("AsyncRedis: Connecting to {}".format(self._dsn))
         try:
-            connection = await aioredis.create_connection(
+            self._connection = await aioredis.from_url(
                 self._dsn,
-                loop=self._loop,
                 encoding=self._encoding,
-                timeout=self._timeout,
-                **kwargs
+                decode_responses=True,
+                **kwargs,
             )
-            self._connection = aioredis.Redis(connection)
-        except (aioredis.ProtocolError, aioredis.AuthError) as err:
+            # self._pool = aioredis.Redis(connection_pool=self._connection)
+        except (aioredis.exceptions.ConnectionError, aioredis.exceptions.AuthenticationError) as err:
             raise ProviderError(
-                "Unable to connect to Redis, connection Refused: {}".format(
-                    str(err)
-                )
+                "Unable to connect to Redis, connection Refused: {}".format(str(err))
             )
         except (aioredis.RedisError, asyncio.TimeoutError) as err:
-            raise ConnectionTimeout(
-                "Unable to connect to Redis: {}".format(str(err))
-            )
+            raise ConnectionTimeout("Unable to connect to Redis: {}".format(str(err)))
         except Exception as err:
             raise ProviderError("Unknown Redis Error: {}".format(str(err)))
             return False
@@ -278,46 +263,37 @@ class redis(BaseProvider):
         if self._connection:
             self._connected = True
             self._initialized_on = time.time()
-
-    async def release(self):
-        """
-        Release a connection and return into pool
-        """
-        if self._pool:
-            await self._pool.release(
-                connection=self._connection.connection
-            )
-        try:
-            await self._connection.quit()
-        except aioredis.errors.ConnectionClosedError as e:
-            self._logger.error(f'Error releasing the Connection {e!s}')
+        return self
 
     def is_closed(self):
         if not self._connection:
             return True
         else:
-            return self._connection.closed
+            return not self._connected
 
-    async def ping(self, msg: str = ''):
-        await self._connection.ping(msg)
+    async def ping(self, msg: str = ""):
+        await self._connection.ping()
 
     async def close(self):
         try:
-            self._connection.close()
-            await asyncio.shield(self._connection.wait_closed())
+            # gracefully closing underlying connection
+            await self._connection.close()
+        except AttributeError:
+            pass
+        except Exception as err:
+            print('Closing: ', err)
+            self._logger.exception(f'Redis Closing Error: {err}')
         finally:
-            self._connection = None
             self._connected = False
 
     async def execute(self, sentence, *args):
         if self._connection:
             try:
-                pass
-                result = await self._connection.execute(sentence, *args)
+                result = await self._connection.execute_command(sentence, *args)
                 return result
             except (
-                aioredis.errors.PoolClosedError,
-                aioredis.errors.ConnectionClosedError,
+                aioredis.RedisError,
+                aioredis.exceptions.ConnectionError,
             ) as err:
                 raise ProviderError("Connection Error: {}".format(str(err)))
 
@@ -328,15 +304,14 @@ class redis(BaseProvider):
         result = None
         error = None
         try:
-            await self.set('test_123', optional)
-            result = await self.get('test_123')
+            await self.set("test_123", optional)
+            result = await self.get("test_123")
         except Exception as err:
             error = err
         finally:
-            await self.delete('test_123')
+            await self.delete("test_123")
             return [result, error]
 
-
     async def query(self, key="", *val):
         return await self.get(key, val)
 
@@ -374,23 +349,19 @@ class redis(BaseProvider):
         if not self._connection:
             await self.connection()
         try:
-            return self._connection.exists(key, *keys)
-        except (aioredis.RedisError, aioredis.ProtocolError) as err:
+            return await self._connection.exists(key, *keys)
+        except (aioredis.RedisError, aioredis.exceptions.ConnectionError) as err:
             raise ProviderError("Redis Exists Error: {}".format(str(err)))
         except Exception as err:
-            raise ProviderError(
-                "Redis Exists Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis Exists Unknown Error: {}".format(str(err)))
 
     async def delete(self, key, *keys):
         try:
             return await self._connection.delete(key, *keys)
-        except (aioredis.RedisError, aioredis.ProtocolError) as err:
+        except (aioredis.RedisError, aioredis.exceptions.ConnectionError) as err:
             raise ProviderError("Redis Exists Error: {}".format(str(err)))
         except Exception as err:
-            raise ProviderError(
-                "Redis Exists Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis Exists Unknown Error: {}".format(str(err)))
 
     async def expire_at(self, key, timestamp):
         try:
@@ -400,9 +371,7 @@ class redis(BaseProvider):
                 "Redis: wrong Expiration timestamp: {}".format(str(timestamp))
             )
         except Exception as err:
-            raise ProviderError(
-                "Redis Expiration Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis Expiration Unknown Error: {}".format(str(err)))
 
     async def setex(self, key, value, timeout):
         """
@@ -423,12 +392,10 @@ class redis(BaseProvider):
             raise ProviderError(
                 "Redis: wrong Expiration timestamp: {}".format(str(timestamp))
             )
-        except (aioredis.RedisError, aioredis.ProtocolError) as err:
+        except (aioredis.RedisError, aioredis.exceptions.ConnectionError) as err:
             raise ProviderError("Redis SetEx Error: {}".format(str(err)))
         except Exception as err:
-            raise ProviderError(
-                "Redis SetEx Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis SetEx Unknown Error: {}".format(str(err)))
 
     def persist(self, key):
         """
@@ -438,9 +405,7 @@ class redis(BaseProvider):
         try:
             return self._connection.persist(key)
         except Exception as err:
-            raise ProviderError(
-                "Redis Expiration Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis Expiration Unknown Error: {}".format(str(err)))
 
     async def set_key(self, key, value):
         await self.set(key, value)
@@ -452,18 +417,16 @@ class redis(BaseProvider):
      Hash functions
     """
 
-    async def hmset(self, key, *args, **kwargs):
+    async def hmset(self, name: str, mapping: dict):
         """
         set the value of a key in field (redis dict)
         """
         try:
-            await self._connection.hmset_dict(key, *args, **kwargs)
-        except (aioredis.RedisError, aioredis.ProtocolError) as err:
+            await self._connection.hmset(name, mapping)
+        except (aioredis.RedisError, aioredis.exceptions.ConnectionError) as err:
             raise ProviderError("Redis Hmset Error: {}".format(str(err)))
         except Exception as err:
-            raise ProviderError(
-                "Redis Hmset Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis Hmset Unknown Error: {}".format(str(err)))
 
     async def hgetall(self, key):
         """
@@ -471,15 +434,13 @@ class redis(BaseProvider):
         """
         try:
             return await self._connection.hgetall(key)
-        except (aioredis.RedisError, aioredis.ProtocolError) as err:
+        except (aioredis.RedisError, aioredis.exceptions.ConnectionError) as err:
             raise ProviderError("Redis Hmset Error: {}".format(str(err)))
         except Exception as err:
-            raise ProviderError(
-                "Redis Hmset Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis Hmset Unknown Error: {}".format(str(err)))
 
-    async def set_hash(self, key, *args, **kwargs):
-        await self.hmset(key, *args, **kwargs)
+    async def set_hash(self, key, kwargs):
+        await self.hmset(key, kwargs)
 
     async def get_hash(self, key):
         return await self.hgetall(key)
@@ -490,12 +451,10 @@ class redis(BaseProvider):
         """
         try:
             return await self._connection.hkeys(key)
-        except (aioredis.RedisError, aioredis.ProtocolError) as err:
+        except (aioredis.RedisError, aioredis.exceptions.ConnectionError) as err:
             raise ProviderError("Redis Hmset Error: {}".format(str(err)))
         except Exception as err:
-            raise ProviderError(
-                "Redis Hmset Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis Hmset Unknown Error: {}".format(str(err)))
 
     async def hvals(self, key):
         """
@@ -503,12 +462,10 @@ class redis(BaseProvider):
         """
         try:
             return await self._connection.hkeys(key)
-        except (aioredis.RedisError, aioredis.ProtocolError) as err:
+        except (aioredis.RedisError, aioredis.exceptions.ConnectionError) as err:
             raise ProviderError("Redis Hmset Error: {}".format(str(err)))
         except Exception as err:
-            raise ProviderError(
-                "Redis Hmset Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis Hmset Unknown Error: {}".format(str(err)))
 
     async def keys(self, key):
         return await self.hkeys(key)
@@ -522,12 +479,10 @@ class redis(BaseProvider):
         """
         try:
             await self._connection.hset(key, field, value)
-        except (aioredis.RedisError, aioredis.ProtocolError) as err:
+        except (aioredis.RedisError, aioredis.exceptions.ConnectionError) as err:
             raise ProviderError("Redis Hset Error: {}".format(str(err)))
         except Exception as err:
-            raise ProviderError(
-                "Redis Hset Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis Hset Unknown Error: {}".format(str(err)))
 
     async def hget(self, key, field):
         """
@@ -535,12 +490,10 @@ class redis(BaseProvider):
         """
         try:
             return await self._connection.hset(key, field)
-        except (aioredis.RedisError, aioredis.ProtocolError) as err:
+        except (aioredis.RedisError, aioredis.exceptions.ConnectionError) as err:
             raise ProviderError("Redis Hget Error: {}".format(str(err)))
         except Exception as err:
-            raise ProviderError(
-                "Redis Hget Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis Hget Unknown Error: {}".format(str(err)))
 
     async def hexists(self, key, field, value):
         """
@@ -548,12 +501,10 @@ class redis(BaseProvider):
         """
         try:
             await self._connection.hexists(key, field)
-        except (aioredis.RedisError, aioredis.ProtocolError) as err:
+        except (aioredis.RedisError, aioredis.exceptions.ConnectionError) as err:
             raise ProviderError("Redis hash exists Error: {}".format(str(err)))
         except Exception as err:
-            raise ProviderError(
-                "Redis hash exists Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis hash exists Unknown Error: {}".format(str(err)))
 
     async def hdel(self, key, field, *fields):
         """
@@ -561,12 +512,21 @@ class redis(BaseProvider):
         """
         try:
             await self._connection.hdel(key, field, *fields)
-        except (aioredis.RedisError, aioredis.ProtocolError) as err:
+        except (aioredis.RedisError, aioredis.exceptions.ConnectionError) as err:
             raise ProviderError("Redis Hset Error: {}".format(str(err)))
         except Exception as err:
-            raise ProviderError(
-                "Redis Hset Unknown Error: {}".format(str(err))
-            )
+            raise ProviderError("Redis Hset Unknown Error: {}".format(str(err)))
+
+    async def lrange(self, key, start: int = 0, stop: int = 100):
+        """
+        Delete one or more hash fields
+        """
+        try:
+            await self._connection.lrange(key, start, stop)
+        except (aioredis.RedisError, aioredis.exceptions.ConnectionError) as err:
+            raise ProviderError("Redis lrange Error: {}".format(str(err)))
+        except Exception as err:
+            raise ProviderError("Redis lrange Unknown Error: {}".format(str(err)))
 
 
 """
