@@ -29,7 +29,7 @@ from rethinkdb.errors import (
     ReqlOpFailedError,
     ReqlOpIndeterminateError,
     ReqlResourceLimitError,
-    ReqlRuntimeError
+    ReqlRuntimeError,
 )
 
 from asyncdb.exceptions import (
@@ -50,6 +50,7 @@ from . import (
 
 rt = RethinkDB()
 
+
 class rethink(BaseProvider):
     _provider = "rethinkdb"
     _syntax = "rql"
@@ -75,7 +76,7 @@ class rethink(BaseProvider):
     distinct = None
 
     def __init__(self, loop=None, params={}, **kwargs):
-        super(rethink, self).__init__(loop=loop, params=params)
+        super(rethink, self).__init__(loop=loop, params=params, **kwargs)
         if loop:
             self._loop = loop
         else:
@@ -87,33 +88,27 @@ class rethink(BaseProvider):
         self._engine.set_loop_type("asyncio")
         asyncio.set_event_loop(self._loop)
 
-
     async def connection(self):
         self._logger.debug(
             "RT Connection to host {} on port {} to database {}".format(
                 self._params["host"], self._params["port"], self._params["db"]
             )
         )
+        self._params["timeout"] = self._timeout
         try:
             self._connection = await self._engine.connect(**self._params)
             if self._params["db"]:
                 await self.db(self._params["db"])
         except ReqlRuntimeError as err:
-            error = "No database connection could be established: {}".format(
-                str(err)
-            )
+            error = "No database connection could be established: {}".format(str(err))
             raise ProviderError(message=error, code=503)
             return False
         except ReqlDriverError as err:
-            error = "No database connection could be established: {}".format(
-                str(err)
-            )
+            error = "No database connection could be established: {}".format(str(err))
             raise ProviderError(message=error, code=503)
             return False
         except Exception as err:
-            error = "Exception on RethinkDB: {}".format(
-                str(err)
-            )
+            error = "Exception on RethinkDB: {}".format(str(err))
             raise ProviderError(message=error, code=503)
             return False
         finally:
@@ -169,12 +164,9 @@ class rethink(BaseProvider):
         ------
         """
         try:
-            if dbname not in await self._engine.db_list().run(
-                self._connection
-            ):
+            if dbname not in await self._engine.db_list().run(self._connection):
                 self._db = dbname
-                return await self._engine.db_create(self._db
-                                                    ).run(self._connection)
+                return await self._engine.db_create(self._db).run(self._connection)
         finally:
             self._db = dbname
             return self
@@ -198,13 +190,9 @@ class rethink(BaseProvider):
             if table in await self._engine.db(self._db).table_list().run(
                 self._connection
             ):
-                return await self._engine.table(table).sync().run(
-                    self._connection
-                )
+                return await self._engine.table(table).sync().run(self._connection)
 
-    async def createindex(
-        self, table, field="", name="", fields=[], multi=True
-    ):
+    async def createindex(self, table, field="", name="", fields=[], multi=True):
         """
         CreateIndex
               create and index into a field or multiple fields
@@ -217,9 +205,9 @@ class rethink(BaseProvider):
                 if field:
                     try:
                         return (
-                            await self._engine.table(table).index_create(
-                                field, multi=multi
-                            ).run(self._connection)
+                            await self._engine.table(table)
+                            .index_create(field, multi=multi)
+                            .run(self._connection)
                         )
                     except ReqlOpFailedError as err:
                         raise ProviderError(message=err, code=503)
@@ -231,9 +219,9 @@ class rethink(BaseProvider):
                         idx.append(self._engine.row(field))
                     try:
                         return (
-                            await self._engine.table(table).index_create(
-                                name, idx
-                            ).run(self._connection)
+                            await self._engine.table(table)
+                            .index_create(name, idx)
+                            .run(self._connection)
                         )
                     except (ReqlDriverError, ReqlRuntimeError):
                         return False
@@ -248,16 +236,15 @@ class rethink(BaseProvider):
         try:
             if pk:
                 return (
-                    await self._engine.db(
-                        self._db
-                    ).table_create(table,
-                                   primary_key=pk).run(self._connection)
+                    await self._engine.db(self._db)
+                    .table_create(table, primary_key=pk)
+                    .run(self._connection)
                 )
             else:
                 return (
-                    await self._engine.db(self._db).table_create(table).run(
-                        self._connection
-                    )
+                    await self._engine.db(self._db)
+                    .table_create(table)
+                    .run(self._connection)
                 )
         finally:
             return self
@@ -271,9 +258,7 @@ class rethink(BaseProvider):
         if self.conditions:
             conditions = {**conditions, **self.conditions}
 
-        conditions.update(
-            (x, None) for (x, y) in conditions.items() if y == "null"
-        )
+        conditions.update((x, None) for (x, y) in conditions.items() if y == "null")
         print("Conditions for clean {}".format(conditions))
 
         try:
@@ -282,7 +267,7 @@ class rethink(BaseProvider):
         except (KeyError, ValueError):
             conditions["filterdate"] = today(mask="%Y-%m-%d")
         result = await self.delete(table, filter=conditions, changes=False)
-        print(result)
+        # print(result)
         if result:
             return result
         else:
@@ -301,8 +286,7 @@ class rethink(BaseProvider):
     async def list_tables(self):
         if self._connection:
             future = asyncio.Future()
-            lists = await self._engine.db(self._db
-                                          ).table_list().run(self._connection)
+            lists = await self._engine.db(self._db).table_list().run(self._connection)
             future.set_result(lists)
             return [x for x in lists]
         else:
@@ -311,16 +295,13 @@ class rethink(BaseProvider):
     async def drop_table(self, table):
         try:
             future = asyncio.Future()
-            lists = await self._engine.db(self._db
-                                          ).table_list().run(self._connection)
+            lists = await self._engine.db(self._db).table_list().run(self._connection)
             future.set_result(list)
             if not table in [x for x in lists]:
                 error = "Table {} not exists in database".format(table)
                 raise ProviderError(error)
             return (
-                await
-                self._engine.db(self._db
-                                ).table_drop(table).run(self._connection)
+                await self._engine.db(self._db).table_drop(table).run(self._connection)
             )
         except (ReqlDriverError, ReqlRuntimeError) as err:
             raise ProviderError(str(err))
@@ -362,23 +343,25 @@ class rethink(BaseProvider):
             try:
                 # self._columns = await self._engine.table(table).get(1).keys().run(self._connection)
                 self._columns = (
-                    await
-                    self._engine.table(table).nth(0).default(None).keys().run(
-                        self._connection
-                    )
+                    await self._engine.table(table)
+                    .nth(0)
+                    .default(None)
+                    .keys()
+                    .run(self._connection)
                 )
                 # print(self._columns)
                 if not filter:
                     cursor = (
-                        await
-                        self._engine.db(self._db
-                                        ).table(table).run(self._connection)
+                        await self._engine.db(self._db)
+                        .table(table)
+                        .run(self._connection)
                     )
                 else:
                     cursor = (
-                        await self._engine.db(
-                            self._db
-                        ).table(table).filter(filter).run(self._connection)
+                        await self._engine.db(self._db)
+                        .table(table)
+                        .filter(filter)
+                        .run(self._connection)
                     )
                 while await cursor.fetch_next():
                     row = await cursor.next()
@@ -415,9 +398,10 @@ class rethink(BaseProvider):
             # startTime = datetime.now()
             try:
                 data = (
-                    await self._engine.table(table).filter(filter).nth(id).run(
-                        self._connection
-                    )
+                    await self._engine.table(table)
+                    .filter(filter)
+                    .nth(id)
+                    .run(self._connection)
                 )
                 if data:
                     self._result = data
@@ -454,9 +438,7 @@ class rethink(BaseProvider):
 
         if self._connection:
             try:
-                data = await self._engine.table(table).get(id).run(
-                    self._connection
-                )
+                data = await self._engine.table(table).get(id).run(self._connection)
                 if data:
                     self._result = data
                 else:
@@ -484,17 +466,15 @@ class rethink(BaseProvider):
             try:
                 if index:
                     cursor = (
-                        await
-                        self._engine.table(table).get_all(filter,
-                                                          index=index).run(
-                                                              self._connection
-                                                          )
+                        await self._engine.table(table)
+                        .get_all(filter, index=index)
+                        .run(self._connection)
                     )
                 else:
                     cursor = (
-                        await self._engine.table(table).get_all(filter).run(
-                            self._connection
-                        )
+                        await self._engine.table(table)
+                        .get_all(filter)
+                        .run(self._connection)
                     )
                 data = []
                 while await cursor.fetch_next():
@@ -521,10 +501,9 @@ class rethink(BaseProvider):
         if self._connection:
             try:
                 data = (
-                    await self._engine.table(table).
-                    filter(lambda doc: doc[field].match(regexp)).run(
-                        self._connection
-                    )
+                    await self._engine.table(table)
+                    .filter(lambda doc: doc[field].match(regexp))
+                    .run(self._connection)
                 )
                 if data:
                     self._result = data
@@ -545,17 +524,13 @@ class rethink(BaseProvider):
         if self._connection:
             try:
                 inserted = (
-                    await
-                    self._engine.table(table).insert(data,
-                                                     conflict="replace").run(
-                                                         self._connection
-                                                     )
+                    await self._engine.table(table)
+                    .insert(data, conflict="replace")
+                    .run(self._connection)
                 )
                 if inserted["errors"] > 0:
                     raise ProviderError(
-                        "INSERT Runtime Error: {}".format(
-                            inserted["first_error"]
-                        )
+                        "INSERT Runtime Error: {}".format(inserted["first_error"])
                     )
                     return False
                 return inserted
@@ -580,15 +555,14 @@ class rethink(BaseProvider):
         if self._connection:
             try:
                 self._result = (
-                    await self._engine.table(table).get(id).replace(data).run(
-                        self._connection
-                    )
+                    await self._engine.table(table)
+                    .get(id)
+                    .replace(data)
+                    .run(self._connection)
                 )
                 if self._result["errors"] > 0:
                     raise ProviderError(
-                        "REPLACE Runtime Error: {}".format(
-                            self._result["first_error"]
-                        )
+                        "REPLACE Runtime Error: {}".format(self._result["first_error"])
                     )
                     return False
                 return self._result
@@ -612,10 +586,10 @@ class rethink(BaseProvider):
             if id:
                 try:
                     self._result = (
-                        await
-                        self._engine.table(table).get(id).update(data).run(
-                            self._connection
-                        )
+                        await self._engine.table(table)
+                        .get(id)
+                        .update(data)
+                        .run(self._connection)
                     )
                     # self._result = await self._engine.table(table).get(id).update(data).run(self._connection)
                     return self._result
@@ -624,16 +598,15 @@ class rethink(BaseProvider):
                     raise ProviderError(error)
                     return False
                 except ReqlNonExistenceError:
-                    raise ProviderError(
-                        "Object {} doesnt exists".format(table)
-                    )
+                    raise ProviderError("Object {} doesnt exists".format(table))
                     return False
             elif type(filter) == dict and len(filter) > 0:
                 try:
                     self._result = (
-                        await self._engine.table(table).filter(filter).update(
-                            data, return_changes=False
-                        ).run(self._connection)
+                        await self._engine.table(table)
+                        .filter(filter)
+                        .update(data, return_changes=False)
+                        .run(self._connection)
                     )
                     # self._result = await self._engine.table(table).filter(filter).update(data).run(self._connection)
                     return self._result
@@ -642,16 +615,12 @@ class rethink(BaseProvider):
                     raise ProviderError(error)
                     return False
                 except ReqlNonExistenceError:
-                    raise ProviderError(
-                        "Object {} doesnt exists".format(table)
-                    )
+                    raise ProviderError("Object {} doesnt exists".format(table))
                     return False
             else:
                 # update all documents in table
                 return (
-                    await self._engine.table(table).update(data).run(
-                        self._connection
-                    )
+                    await self._engine.table(table).update(data).run(self._connection)
                 )
         else:
             return False
@@ -664,9 +633,9 @@ class rethink(BaseProvider):
         if self._connection:
             try:
                 self._result = (
-                    await self._engine.table(table).get(id).update(
-                        {field: r.literal(data).run(self._connection)}
-                    )
+                    await self._engine.table(table)
+                    .get(id)
+                    .update({field: r.literal(data).run(self._connection)})
                 )
                 return self._result
             except ReqlRuntimeError as err:
@@ -679,9 +648,7 @@ class rethink(BaseProvider):
         else:
             return False
 
-    async def update_conditions(
-        self, table, data, filter={}, fieldname="filterdate"
-    ):
+    async def update_conditions(self, table, data, filter={}, fieldname="filterdate"):
         """
         update_conditions
              update a record based on a fieldname
@@ -690,9 +657,11 @@ class rethink(BaseProvider):
         if self._connection:
             try:
                 self._result = (
-                    await self._engine.table(table).filter(
-                        ~self._engine.row.has_fields(fieldname)
-                    ).filter(filter).update(data).run(self._connection)
+                    await self._engine.table(table)
+                    .filter(~self._engine.row.has_fields(fieldname))
+                    .filter(filter)
+                    .update(data)
+                    .run(self._connection)
                 )
                 return self._result
             except ReqlRuntimeError as err:
@@ -718,9 +687,10 @@ class rethink(BaseProvider):
             if id:
                 try:
                     self._result = (
-                        await self._engine.table(table).get(id).delete(
-                            return_changes=changes
-                        ).run(self._connection)
+                        await self._engine.table(table)
+                        .get(id)
+                        .delete(return_changes=changes)
+                        .run(self._connection)
                     )
                     return self._result
                 except (ReqlRuntimeError, ReqlRuntimeError, ReqlError) as err:
@@ -729,9 +699,10 @@ class rethink(BaseProvider):
             elif isinstance(filter, dict):
                 try:
                     self._result = (
-                        await self._engine.table(table).filter(filter).delete(
-                            return_changes=changes
-                        ).run(self._connection)
+                        await self._engine.table(table)
+                        .filter(filter)
+                        .delete(return_changes=changes)
+                        .run(self._connection)
                     )
                     return self._result
                 except (ReqlRuntimeError, ReqlRuntimeError, ReqlError) as err:
@@ -740,9 +711,9 @@ class rethink(BaseProvider):
             else:
                 # delete all documents in table
                 return (
-                    await
-                    self._engine.table(table).delete(return_changes=changes
-                                                     ).run(self._connection)
+                    await self._engine.table(table)
+                    .delete(return_changes=changes)
+                    .run(self._connection)
                 )
         else:
             return False
@@ -769,15 +740,16 @@ class rethink(BaseProvider):
             try:
                 if idx:
                     cursor = (
-                        await self._engine.table(table).order_by(
-                            index=idx
-                        ).between(m, mx, index=idx).run(self._connection)
+                        await self._engine.table(table)
+                        .order_by(index=idx)
+                        .between(m, mx, index=idx)
+                        .run(self._connection)
                     )
                 else:
                     cursor = (
-                        await self._engine.table(table).between(m, mx).run(
-                            self._connection
-                        )
+                        await self._engine.table(table)
+                        .between(m, mx)
+                        .run(self._connection)
                     )
                 data = []
                 while await cursor.fetch_next():
@@ -873,20 +845,17 @@ class rethink(BaseProvider):
                     # elif is_program_date(value):
                     #    val = get_program_date(value)
                     #    self.conditions[key] = "{}".format(val)
-                    elif self.cond_definition and self.cond_definition[
-                        key] == "field":
+                    elif self.cond_definition and self.cond_definition[key] == "field":
                         self.conditions[key] = "{}".format(value)
                     elif value == "null" or value == "NULL":
                         self.conditions[key] = "null"
                     elif (
-                        self.cond_definition
-                        and self.cond_definition[key] == "boolean"
+                        self.cond_definition and self.cond_definition[key] == "boolean"
                     ):
                         self.conditions[key] = value
                     elif isinteger(value) or isnumber(value):
                         self.conditions[key] = value
-                    elif self.cond_definition and self.cond_definition[
-                        key] == "date":
+                    elif self.cond_definition and self.cond_definition[key] == "date":
                         self.conditions[key] = value.replace("'", "")
                     else:
                         print("RT condition %s for value %s" % (key, value))
@@ -909,7 +878,8 @@ class rethink(BaseProvider):
             if hierarchy:
                 try:
                     get_filter = [
-                        k.replace("!", "") for k in conditions
+                        k.replace("!", "")
+                        for k in conditions
                         if k.replace("!", "") in hierarchy
                     ]
                     filter_sorted = sorted(get_filter, key=hierarchy.index)
@@ -919,7 +889,7 @@ class rethink(BaseProvider):
                 try:
                     get_index = hierarchy.index(filter_sorted.pop())
                     # print(get_index)
-                    selected = hierarchy[get_index + 1:]
+                    selected = hierarchy[get_index + 1 :]
                 except (KeyError, IndexError):
                     selected = []
                 try:
@@ -927,9 +897,7 @@ class rethink(BaseProvider):
                         # print('null all conditions below selection')
                         if selected:
                             for n in selected:
-                                result = result.and_(
-                                    self._engine.row[n].eq(None)
-                                )
+                                result = result.and_(self._engine.row[n].eq(None))
                         else:
                             if get_filter:
                                 last = get_filter.pop(0)
@@ -945,53 +913,39 @@ class rethink(BaseProvider):
                                     )
                             else:
                                 last = hierarchy.pop(0)
-                                result = result.and_(
-                                    self._engine.row[last].eq(None)
-                                )
+                                result = result.and_(self._engine.row[last].eq(None))
                 except (KeyError, ValueError):
                     pass
                 try:
                     if self.qry_options["select_child"] == "true":
                         try:
                             child = selected.pop(0)
-                            result = result.and_(
-                                self._engine.row[child].ne(None)
-                            )
+                            result = result.and_(self._engine.row[child].ne(None))
                             # _where[child] = '!null'
                             for n in selected:
-                                result = result.and_(
-                                    self._engine.row[n].eq(None)
-                                )
+                                result = result.and_(self._engine.row[n].eq(None))
                             return result
                         except (ValueError, IndexError):
                             if get_filter:
                                 pass
                             else:
                                 child = hierarchy.pop(0)
-                                result = result.and_(
-                                    self._engine.row[child].ne(None)
-                                )
+                                result = result.and_(self._engine.row[child].ne(None))
                                 # _where[child] = '!null'
                                 for n in hierarchy:
                                     # _where[n] = 'null'
-                                    result = result.and_(
-                                        self._engine.row[n].eq(None)
-                                    )
+                                    result = result.and_(self._engine.row[n].eq(None))
                 except (KeyError, ValueError):
                     pass
                 try:
                     if self.qry_options["select_stores"] == "true":
                         try:
                             last = selected.pop()
-                            result = result.and_(
-                                self._engine.row[last].ne(None)
-                            )
+                            result = result.and_(self._engine.row[last].ne(None))
                             return result
                         except (ValueError, IndexError):
                             last = hierarchy.pop()
-                            result = result.and_(
-                                self._engine.row[last].ne(None)
-                            )
+                            result = result.and_(self._engine.row[last].ne(None))
                 except (KeyError, ValueError):
                     pass
         return result
@@ -1001,15 +955,14 @@ class rethink(BaseProvider):
         if self._connection:
             try:
                 self._result = (
-                    await self._engine.table(table).filter(filter).nth(id).run(
-                        self._connection
-                    )
+                    await self._engine.table(table)
+                    .filter(filter)
+                    .nth(id)
+                    .run(self._connection)
                 )
                 return self._result
             except ReqlNonExistenceError as err:
-                raise ReqlNonExistenceError(
-                    "Empty Result: {}".format(str(err))
-                )
+                raise ReqlNonExistenceError("Empty Result: {}".format(str(err)))
             except ReqlRuntimeError as err:
                 raise ReqlRuntimeError(str(err))
             except Exception as err:
@@ -1025,9 +978,7 @@ class rethink(BaseProvider):
             conditions = {**self.conditions}
         if self.where:
             conditions.update(self.where)
-        conditions.update(
-            (x, None) for (x, y) in conditions.items() if y == "null"
-        )
+        conditions.update((x, None) for (x, y) in conditions.items() if y == "null")
         try:
             if conditions["filterdate"] == "CURRENT_DATE":
                 conditions["filterdate"] = today(mask="%Y-%m-%d")
@@ -1058,9 +1009,7 @@ class rethink(BaseProvider):
         if self.where:
             conditions.update(self.where)
 
-        conditions.update(
-            (x, None) for (x, y) in conditions.items() if y == "null"
-        )
+        conditions.update((x, None) for (x, y) in conditions.items() if y == "null")
 
         print("RT CONDITIONS {}".format(conditions))
 
@@ -1111,11 +1060,12 @@ class rethink(BaseProvider):
         ### build FILTER based on rethink logic
         for key, value in conditions.items():
             if type(value) is list:
-                print(value)
+                # print(value)
                 search = search.filter(
                     (
-                        lambda exp: self._engine.expr(value).
-                        coerce_to("array").contains(exp[key])
+                        lambda exp: self._engine.expr(value)
+                        .coerce_to("array")
+                        .contains(exp[key])
                     )
                 )
             else:
@@ -1127,9 +1077,7 @@ class rethink(BaseProvider):
                         )
                     elif value.startswith("["):
                         # between
-                        result = result.and_(
-                            self._engine.row[key].between(10, 20)
-                        )
+                        result = result.and_(self._engine.row[key].between(10, 20))
                     else:
                         result = result.and_(self._engine.row[key].eq(value))
                 else:
@@ -1139,8 +1087,8 @@ class rethink(BaseProvider):
         if self.qry_options:
             result = self.query_options(result, conditions)
 
-        print("RESULT IS")
-        print(result)
+        # print("RESULT IS")
+        # print(result)
 
         # add search criteria
         search = search.filter(result)
